@@ -47,7 +47,7 @@ def main():
         help="debug output"
     )
     parser.add_argument(
-        "--kernel_name",
+        "--kernel",
         required=False,
         default=False,
         help="The name of the kernel to use when executing a notebook.",
@@ -57,20 +57,20 @@ def main():
         action="store_true",
         help="Save output to test_results/"
     )
-    parser.add_argument(
-        "--output_ipynb",
-        required=False,
-        default="output.ipynb",
-        help="Output Jupyter notebook filename. The default is a temporary "
-             "file that is not saved.",
-    )
-    parser.add_argument(
-        "--log_file",
-        required=False,
-        default=False,
-        help="Output results of action to a log file. The default is no log"
-             "file.",
-    )
+    # parser.add_argument(
+    #     "--output",
+    #     required=False,
+    #     default="output.ipynb",
+    #     help="Output Jupyter notebook filename. The default is a temporary "
+    #          "file that is not saved.",
+    # )
+    # parser.add_argument(
+    #     "--log",
+    #     required=False,
+    #     default=False,
+    #     help="Output results of action to a log file. The default is no log"
+    #          "file.",
+    # )
 
     # Action arguments - one or more required
     action_arguments = parser.add_argument_group(
@@ -79,8 +79,7 @@ def main():
     action_arguments.add_argument(
         "--execute",
         action="store_true",
-        help="Execute the notebook, optionally save to new file with "
-             "--output_ipynb option.",
+        help="Execute the notebook, output saved to output.ipynb"
     )
     action_arguments.add_argument(
         "--read",
@@ -127,9 +126,9 @@ def main():
     # Check if selected actions are valid
     args = parse_actions(args, parser)
 
-    args.save = (args.save and args.execute and args.kernel_name)
+    args.save = (args.save and args.execute and args.kernel)
     # output_dir = create_output_dir(args)
-    output_dir = create_output_dir(args.save, args.execute, args.kernel_name,
+    output_dir = create_output_dir(args.save, args.execute, args.kernel,
                                    args.debug)
 
     kernel_notebook_test_results = {}
@@ -148,7 +147,7 @@ def main():
         # Run an action with the notebook, e.g. execute, read
         successful_execution, test_result, comparison_result = \
             run_actions(args.execute, args.read, args.test, args.compare,
-                        args.save, args.kernel_name, args.debug,
+                        args.save, args.kernel, args.debug,
                         notebook_filename, output_ipynb, output_log)
 
         # Add to a list of results, to be printed at the end
@@ -161,13 +160,13 @@ def main():
             kernel_test_results = False
 
     assert_final_validation_results(args.execute, args.test, args.compare,
-                                    args.kernel_name,
+                                    args.kernel,
                                     complete_test_result,
                                     kernel_test_results,
                                     kernel_notebook_test_results)
 
 
-def assert_final_validation_results(execute, test, compare, kernel_name,
+def assert_final_validation_results(execute, test, compare, kernel,
                                     complete_test_result,
                                     kernel_test_results,
                                     kernel_notebook_test_results):
@@ -182,7 +181,7 @@ def assert_final_validation_results(execute, test, compare, kernel_name,
 
         print(BLUE, "**", NC, "  Kernel:     ",
               GREEN if kernel_test_results else RED,
-              kernel_name)
+              kernel)
 
         for notebook in kernel_notebook_test_results:
             print(BLUE, "**", NC, "    Notebook: ",
@@ -215,7 +214,7 @@ def parse_actions(args, parser):
         sys.exit()
 
     # Require a kernel to be specified if executing
-    if args.execute and not args.kernel_name:
+    if args.execute and not args.kernel:
         print(RED, "\nKernel name needs to be specified when executing "
                    "notebooks.\n", NC)
         args = parser.parse_args(["-h"])
@@ -224,7 +223,7 @@ def parse_actions(args, parser):
     return args
 
 
-def run_actions(execute, read, test, compare, save, kernel_name, debug,
+def run_actions(execute, read, test, compare, save, kernel, debug,
                 notebook_filename, output_ipynb, output_log):
 
     successful_execution = False
@@ -232,7 +231,7 @@ def run_actions(execute, read, test, compare, save, kernel_name, debug,
     comparison_result = False
 
     print_notebook_information_before(execute, test, compare, save,
-                                      kernel_name,  notebook_filename,
+                                      kernel,  notebook_filename,
                                       output_ipynb, output_log)
 
     # Execute an ipynb notebook, save output to new ipynb notebook
@@ -240,7 +239,7 @@ def run_actions(execute, read, test, compare, save, kernel_name, debug,
 
         # Execute the notebook with papermill
         successful_execution = execute_ipynb_pm(
-            notebook_filename, output_ipynb, kernel_name, debug
+            notebook_filename, output_ipynb, kernel, debug
         )
 
         notebook_to_examine = output_ipynb
@@ -278,7 +277,7 @@ def run_actions(execute, read, test, compare, save, kernel_name, debug,
             debug,
         )
 
-    print_notebook_information_after(execute, test, compare, save, kernel_name,
+    print_notebook_information_after(execute, test, compare, save, kernel,
                                      notebook_filename, output_ipynb,
                                      output_log, successful_execution,
                                      test_result, comparison_result)
@@ -287,7 +286,7 @@ def run_actions(execute, read, test, compare, save, kernel_name, debug,
 
 
 def print_notebook_information_before(execute, test, compare, save,
-                                      kernel_name, notebook_filename,
+                                      kernel, notebook_filename,
                                       output_ipynb, output_log):
 
     # Print something extra if test and comparison will also be done
@@ -295,7 +294,7 @@ def print_notebook_information_before(execute, test, compare, save,
         print("")
         print(CYAN, "*".center(80, "*"), NC)
         print(CYAN, "** STARTING VALIDATIONS FOR:")
-        print(CYAN, "**", NC, "  Kernel:   ", kernel_name)
+        print(CYAN, "**", NC, "  Kernel:   ", kernel)
         print(CYAN, "**", NC, "  Notebook: ", notebook_filename)
         print(CYAN, "** OUTPUT:")
         print(CYAN, "**", NC, "  Notebook:", output_ipynb)
@@ -303,7 +302,7 @@ def print_notebook_information_before(execute, test, compare, save,
         print(CYAN, "*".center(80, "*"), NC)
 
 
-def print_notebook_information_after(execute, test, compare, save, kernel_name,
+def print_notebook_information_after(execute, test, compare, save, kernel,
                                      notebook_filename, output_ipynb,
                                      output_log, successful_execution,
                                      test_result, comparison_result):
@@ -317,7 +316,7 @@ def print_notebook_information_after(execute, test, compare, save, kernel_name,
 
         print(CYAN, "*".center(80, "*"), NC)
         print(CYAN, "** FINISHED VALIDATIONS FOR:")
-        print(CYAN, "**", NC, "  Kernel:   ", kernel_name)
+        print(CYAN, "**", NC, "  Kernel:   ", kernel)
         print(CYAN, "**", NC, "  Notebook: ", notebook_filename)
         print(CYAN, "** OUTPUT:")
         print(CYAN, "**", NC, "  Notebook:", output_ipynb)
