@@ -461,6 +461,7 @@ def examine_output_key_data(key, nb0, nb1, debug):
         "text/html": ["h5glance", "image/png"],
         "application/vnd.jupyter.widget-view+json": ["model_id"],
         "text/plain": ["h5glance", "matplotlib."],
+        "application/x-hdf5": ["."],
     }
 
     for subkey in nb0[key]:
@@ -664,7 +665,7 @@ def parse_compare_input(args_compare, args_execute, debug):
             print("    jnbv file1.ipynb --compare file2.ipynb")
             print(BLUE, "Example of executing a file, then comparing",
                   " the output with the original file:", NC)
-            print("    jnbv file1.ipynb --kernel_name python3 --execute ",
+            print("    jnbv file1.ipynb --kernel python3 --execute ",
                   "--compare\n")
             print(RED, "Assertion Error:", NC)
             raise AssertionError
